@@ -1,11 +1,11 @@
 #!/usr/bin/perl
 
-package JSON::RPC::Common::Procedure::Return::Version_2_0::Error;
+package JSON::RPC::Common::Procedure::Return::Version_1_1::Error;
 BEGIN {
-  $JSON::RPC::Common::Procedure::Return::Version_2_0::Error::VERSION = '0.09';
+  $JSON::RPC::Common::Procedure::Return::Version_1_1::Error::VERSION = '0.10';
 }
 use Moose;
-# ABSTRACT: JSON-RPC 2.0 error class.
+# ABSTRACT: JSON-RPC 1.1 error class.
 
 use JSON::RPC::Common::TypeConstraints qw(JSONValue);
 
@@ -18,17 +18,23 @@ has '+message' => (
 );
 
 has '+code' => (
-	default => -32603,
+	default => 500,
+);
+
+has name => (
+	is      => "rw",
+	default => "JSONRPCError", # fucking idiots
 );
 
 sub deflate {
 	my $self = shift;
 
 	return {
-		code    => $self->code,
+		name    => $self->name,
 		message => $self->message,
-		( $self->has_data ? ( data => $self->data ) : () ),
-	};
+		code    => $self->code,
+		( $self->has_data ? ( error => $self->data ) : () ),
+	},
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -43,11 +49,11 @@ __END__
 
 =head1 NAME
 
-JSON::RPC::Common::Procedure::Return::Version_2_0::Error - JSON-RPC 2.0 error class.
+JSON::RPC::Common::Procedure::Return::Version_1_1::Error - JSON-RPC 1.1 error class.
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -55,10 +61,13 @@ version 0.09
 
 =head1 DESCRIPTION
 
-This class implements 2.0 error objects.
+This class implements 1.1 error objects.
 
 C<code> and C<message> are mandatory.
 
+The C<data> field is named C<error> in the deflated version and C<name> is set
+to C<JSONRPCError>. How exciting.
+
 See L<JSON::RPC::Common::Procedure::Return::Error>.
 
 =head1 AUTHOR
